@@ -50,7 +50,8 @@ class NSSGenerator(ConfigGenerator):
         'X448': '',
         'SECP256R1': 'SECP256R1',
         'SECP384R1': 'SECP384R1',
-        'SECP521R1': 'SECP521R1'
+        'SECP521R1': 'SECP521R1',
+        'X25519-KYBER768': 'XYBER768D00',
     }
 
     cipher_map = {
@@ -147,8 +148,8 @@ class NSSGenerator(ConfigGenerator):
             except KeyError:
                 pass
 
-        # option not in Fedora yet, default to True
-        no_tls_require_ems = os.getenv('NSS_NO_TLS_REQUIRE_EMS', '1') == '1'
+        # Fedora ELN has the default flipped because it doesn't carry the patch
+        no_tls_require_ems = os.getenv('NSS_NO_TLS_REQUIRE_EMS', '0') == '1'
         if policy.enums['__ems'] == 'ENFORCE' and not no_tls_require_ems:
             s = cls.append(s, 'TLS-REQUIRE-EMS')
 
